@@ -120,7 +120,7 @@ void MainWindow::save_ini()
     settings.endGroup();
     settings.beginGroup("LoSet");
     settings.setValue("incbadflag", ui->checkBox_incbadflags->isChecked());
-    settings.setValue("incgainroot", ui->checkBox_incgainroot->isChecked());
+    settings.setValue("reboot", ui->checkBox_reboot->isChecked());
     settings.setValue("savewidget", ui->checkBox_exitsave->isChecked());
     settings.setValue("savelist", ui->checkBox_exitsavelist->isChecked());
     settings.setValue("loadlist", ui->checkBox_loadliststart->isChecked());
@@ -211,7 +211,7 @@ void MainWindow::load_ini()
         settings.endGroup();
         settings.beginGroup("LoSet");
         ui->checkBox_incbadflags->setChecked(settings.value("incbadflag").toBool());
-        ui->checkBox_incgainroot->setChecked(settings.value("incgainroot").toBool());
+        ui->checkBox_reboot->setChecked(settings.value("reboot").toBool());
         ui->checkBox_exitsave->setChecked(settings.value("savewidget").toBool());
         ui->checkBox_exitsavelist->setChecked(settings.value("savelist").toBool());
         ui->checkBox_loadliststart->setChecked(settings.value("loadlist").toBool());
@@ -362,6 +362,10 @@ void MainWindow::on_tabWidget_local_currentChanged(int index)
         ui->textEdit_lsof->setMinimumSize(0,0);
         ui->textEdit_lsof->setText(getlsof());
     }
+    else if (index==6)
+    {
+        checkbootfile();
+    }
 }
 
 
@@ -481,18 +485,6 @@ void MainWindow::on_pushButton_stop_clicked()
 
         out << "#!/bin/sh" << "\n";
         out << "\n";
-        if (ui->checkBox_incgainroot->checkState())
-        {
-            out << "# gain superuser rights." << "\n";
-            out << "\n";
-            out << "if [ `id -u` != 0 ] ; then" << "\n";
-            out << "exec sudo gainroot <<EOF" << "\n";
-            out << "exec sh $0 $*" << "\n";
-            out << "EOF" << "\n";
-            out << "exit $?" << "\n";
-            out << "fi   " << "\n";
-        }
-        out << "\n";
         out << "IPT=\"iptables\"" << "\n";
         out << "cat /proc/sys/net/ipv4/ip_forward >/dev/null;" << "\n";
         out << "if [ $? -eq 1 ]" << "\n";
@@ -590,18 +582,6 @@ void MainWindow::write_wall()
 
     out << "#!/bin/sh" << "\n";
     out << "\n";
-    if (ui->checkBox_incgainroot->checkState())
-    {
-        out << "# gain superuser rights." << "\n";
-        out << "\n";
-        out << "if [ `id -u` != 0 ] ; then" << "\n";
-        out << "exec sudo gainroot <<EOF" << "\n";
-        out << "exec sh $0 $*" << "\n";
-        out << "EOF" << "\n";
-        out << "exit $?" << "\n";
-        out << "fi   " << "\n";
-    }
-    out << "\n";
     out << "IPT=\"iptables\"" << "\n";
     out << "WAN=\"" << (ui->comboBox_wandev->currentText()) << "0\"" << "\n";
     out << "LAN=\"" << (ui->comboBox_landev->currentText()) << "0\"" << "\n";
@@ -1035,36 +1015,41 @@ void MainWindow::on_pushButton_loadini_clicked()
 
 void MainWindow::on_pushButton_delboot_clicked()
 {
-    QMessageBox msgBox;
-    msgBox.setText("Delete iptables boot rules?");
-    msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
-    msgBox.setDefaultButton(QMessageBox::No);
     QFile file("/etc/network/if-up.d/iptables");
-    //if(msgBox.exec() == QMessageBox::Yes)
-    if(msgBox.exec() == QMessageBox::Yes && file.exists())
+    if(file.exists())
     {
-        if (file.remove())
+        QMessageBox msgBox;
+        msgBox.setText("Delete iptables boot rules?");
+        msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
+        msgBox.setDefaultButton(QMessageBox::No);
+        if(msgBox.exec() == QMessageBox::Yes)
         {
-            QMaemo5InformationBox::information(this, "deleted boot rules",
-                                               QMaemo5InformationBox::DefaultTimeout);
+            if (file.remove())
+            {
+                QMaemo5InformationBox::information(this, "deleted boot rules",
+                                                   QMaemo5InformationBox::DefaultTimeout);
+            }
+            else {
+                QMessageBox::information(0, "error", file.errorString());
+            }
         }
-        else {
-            QMessageBox::information(0, "error", file.errorString());
-        }
-    }
-    else {
-        QMaemo5InformationBox::information(this, "no file to delete",
-                                           QMaemo5InformationBox::DefaultTimeout);
+        checkbootfile();
     }
 }
 
 void MainWindow::on_pushButton_deleteset_clicked()
 {
-
-    ui->checkBox_exitsave->setChecked(false);
-    ui->checkBox_exitsavelist->setChecked(false);
-    deleteSettings("/home/user/.genwall/");
-    this->close();
+    QMessageBox msgBox;
+    msgBox.setText("Delete all saved settings?");
+    msgBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
+    msgBox.setDefaultButton(QMessageBox::No);
+    if(msgBox.exec() == QMessageBox::Yes)
+    {
+        ui->checkBox_exitsave->setChecked(false);
+        ui->checkBox_exitsavelist->setChecked(false);
+        deleteSettings("/home/user/.genwall/");
+        this->close();
+    }
 }
 
 void MainWindow::deleteSettings(QString gendir)
@@ -2321,7 +2306,7 @@ void MainWindow::wload_ini()
     QFileInfo fi("/home/user/.genwall/network.ini");
     if (!fi.exists())
     {
-        QMaemo5InformationBox::information(this, "no file found", QMaemo5InformationBox::DefaultTimeout);
+        QMaemo5InformationBox::information(this, "no settings file found default values set", QMaemo5InformationBox::DefaultTimeout);
     }
     else
     {
@@ -2683,11 +2668,6 @@ void MainWindow::on_pushButton_btonoff_clicked()
         //qDebug() << path.path();
         }*/
 
-
-
-
-
-
 }
 
 void MainWindow::on_pushButton_btstartstop_clicked()
@@ -2697,4 +2677,11 @@ void MainWindow::on_pushButton_btstartstop_clicked()
     process->waitForFinished();
 }
 
-
+void MainWindow::checkbootfile()
+{
+    QFile file("/etc/network/if-up.d/iptables");
+    if(file.exists())
+        ui->pushButton_delboot->setStyleSheet("QPushButton { color : green; }");
+    else
+        ui->pushButton_delboot->setStyleSheet("QPushButton { color : red; }");
+}
